@@ -48,13 +48,20 @@ get_data_list <- function(analysis_type, family, link, meth, Mlist, K, auxvars,
   }
 
   # hyperparameters imputation models
-  if (any(meth %in% c("norm", "lognorm"))) {
+  if (any(meth %in% c("norm"))) {
     l$mu_reg_norm <- defs$norm["mu_reg_norm"]
     l$tau_reg_norm <- defs$norm["tau_reg_norm"]
     l$a_tau_norm <- defs$norm["a_tau_norm"]
     l$b_tau_norm <- defs$norm["b_tau_norm"]
   }
 
+  if (any(meth %in% c("lognorm"))) {
+    l$mu_reg_lognorm <- defs$norm["mu_reg_norm"]
+    l$tau_reg_lognorm <- defs$norm["tau_reg_norm"]
+    l$a_tau_lognorm <- defs$norm["a_tau_norm"]
+    l$b_tau_lognorm <- defs$norm["b_tau_norm"]
+  }
+
   if (any(meth %in% c("gamma"))) {
     l$mu_reg_gamma <- defs$gamma["mu_reg_gamma"]
     l$tau_reg_gamma <- defs$gamma["tau_reg_gamma"]
@@ -107,7 +114,8 @@ get_data_list <- function(analysis_type, family, link, meth, Mlist, K, auxvars,
 
 
 #' Get default values for hyperparameters
-#' Prints the list of default values for the hyperparameters
+#'
+#' Prints the list of default values for the hyperparameters.
 #' @param family distribution family of the analysis model
 #'               (\code{gaussian}, \code{binomial}, \code{poisson} or \code{Gamma})
 #' @param link link function (if the link is already given in the family,
@@ -123,53 +131,53 @@ get_data_list <- function(analysis_type, family, link, meth, Mlist, K, auxvars,
 #' \tabular{ll}{
 #' \code{mu_reg_main} \tab mean in the priors for regression coefficients\cr
 #' \code{tau_reg_main} \tab precision in the priors for regression coefficients\cr
-#' \code{a_tau_main} \tab scale parameter in gamma prior for precision of outcome\cr
-#' \code{b_tau_main} \tab rate parameter in gamma prior for precision of outcome\cr
+#' \code{a_tau_main} \tab scale parameter in Gamma prior for precision of outcome\cr
+#' \code{b_tau_main} \tab rate parameter in Gamma prior for precision of outcome
 #' }
 #'
 #' \strong{Z:} hyperparameters for the random effects in mixed models
 #' \tabular{ll}{
 #' \code{RinvD} \tab scale matrix in Wishart prior (*) for random effects covariance matrix\cr
 #' \code{KinvD} \tab degrees of freedom in Wishart prior for random effects covariance matrix\cr
-#' \code{a_diag_RinvD} \tab scale parameter in gamma prior for the diagonal elements of \code{RinvD}\cr
-#' \code{b_diag_RinvD} \tab rate parameter in gamma prior for the diagonal elements of \code{RinvD}\cr
+#' \code{a_diag_RinvD} \tab scale parameter in Gamma prior for the diagonal elements of \code{RinvD}\cr
+#' \code{b_diag_RinvD} \tab rate parameter in Gamma prior for the diagonal elements of \code{RinvD}
 #' }
-#' (*) when there is only one random effect a gamma distribution is used instead of the Wishart
+#' (*) when there is only one random effect a Gamma distribution is used instead of the Wishart
 #'
 #' \strong{norm:} hyperparameters for normal and lognormal imputation models
 #' \tabular{ll}{
 #' \code{mu_reg_norm} \tab mean in the priors for regression coefficients\cr
 #' \code{tau_reg_norm} \tab precision in the priors for regression coefficients\cr
-#' \code{a_tau_norm} \tab scale parameter in gamma prior for precision of imputed variable\cr
-#' \code{b_tau_norm} \tab rate parameter in gamma prior for precision of imputed variable\cr
+#' \code{a_tau_norm} \tab scale parameter in Gamma prior for precision of imputed variable\cr
+#' \code{b_tau_norm} \tab rate parameter in Gamma prior for precision of imputed variable
 #' }
 #'
-#' \strong{gamma:} hyperparameters for gamma imputation models
+#' \strong{gamma:} hyperparameters for Gamma imputation models
 #' \tabular{ll}{
 #' \code{mu_reg_gamma} \tab mean in the priors for regression coefficients\cr
 #' \code{tau_reg_gamma} \tab precision in the priors for regression coefficients\cr
-#' \code{a_tau_gamma} \tab scale parameter in gamma prior for precision of imputed variable\cr
-#' \code{b_tau_gamma} \tab rate parameter in gamma prior for precision of imputed variable\cr
+#' \code{a_tau_gamma} \tab scale parameter in Gamma prior for precision of imputed variable\cr
+#' \code{b_tau_gamma} \tab rate parameter in Gamma prior for precision of imputed variable
 #' }
 #'
 #' \strong{beta:} hyperparameters for beta imputation models
 #' \tabular{ll}{
 #' \code{mu_reg_beta} \tab mean in the priors for regression coefficients\cr
 #' \code{tau_reg_beta} \tab precision in the priors for regression coefficients\cr
-#' \code{a_tau_beta} \tab scale parameter in gamma prior for precision of imputed variable\cr
-#' \code{b_tau_beta} \tab rate parameter in gamma prior for precision of imputed variable\cr
+#' \code{a_tau_beta} \tab scale parameter in Gamma prior for precision of imputed variable\cr
+#' \code{b_tau_beta} \tab rate parameter in Gamma prior for precision of imputed variable
 #' }
 #'
 #' \strong{logit:} hyperparameters for logistic imputation models
 #' \tabular{ll}{
 #' \code{mu_reg_logit} \tab mean in the priors for regression coefficients\cr
-#' \code{tau_reg_logit} \tab precision in the priors for regression coefficients\cr
+#' \code{tau_reg_logit} \tab precision in the priors for regression coefficients
 #' }
 #'
 #' \strong{multinomial:} hyperparameters for multinomial imputation models
 #' \tabular{ll}{
 #' \code{mu_reg_multinomial} \tab mean in the priors for regression coefficients\cr
-#' \code{tau_reg_multinomial} \tab precision in the priors for regression coefficients\cr
+#' \code{tau_reg_multinomial} \tab precision in the priors for regression coefficients
 #' }
 #'
 #' \strong{ordinal:} hyperparameters for ordinal imputation models
@@ -177,10 +185,14 @@ get_data_list <- function(analysis_type, family, link, meth, Mlist, K, auxvars,
 #' \code{mu_reg_ordinal} \tab mean in the priors for regression coefficients\cr
 #' \code{tau_reg_ordinal} \tab precision in the priors for regression coefficients\cr
 #' \code{mu_delta_ordinal} \tab mean in the prior for the intercepts\cr
-#' \code{tau_delta_ordinal} \tab precision in the priors for the intercepts\cr
+#' \code{tau_delta_ordinal} \tab precision in the priors for the intercepts
 #' }
 #'
-
+#'
+#' @examples
+#' default_hyperpars()
+#'
+#'
 #' @export
 
 default_hyperpars <- function(family = 'gaussian', link = "identity", nranef = NULL) {
