@@ -1,35 +1,29 @@
 #' Summary of an object of class JointAI
-#' @param object object inheriting from class \code{JointAI}
-#' @param start the first iteration of interest (see \code{\link[coda]{window.mcmc}})
-#' @param end the last iteration of interest (see \code{\link[coda]{window.mcmc}})
-#' @param thin thinning interval (see \code{\link[coda]{window.mcmc}})
-#' @inheritParams coda::window.mcmc
+#'
+#' \code{summary} method for class "JointAI".
 #' @inheritParams base::print
 #' @param quantiles posterior quantiles
-#' @param subset subset of monitored parameters (columns in the MCMC sample).
-#'               Can be specified as a numeric vector of columns, a vector of
-#'               column names, as \code{subset = "main"} or \code{NULL}.
-#'               If \code{NULL}, all monitored nodes will be plotted.
-#'               \code{subset = "main"} (default) the main parameters of the
-#'               analysis model will be plotted (regression coefficients/fixed
-#'               effects, and, if available, standard deviation of the residual
-#'               and random effects covariance matrix).
-#' @param ... currently not used
+#' @inheritParams sharedParams
+#' @param \dots currently not used
 #'
 #' @examples
 #' mod1 <- lm_imp(y~C1 + C2 + M2, data = wideDF, n.iter = 100)
+#'
 #' summary(mod1)
 #'
 #'
 #' @seealso The model fitting functions \code{\link{lm_imp}},
-#'          \code{\link{glm_imp}}, \code{\link{lme_imp}}
+#'          \code{\link{glm_imp}}, \code{\link{lme_imp}} and the
+#'          vignette \href{https://nerler.github.io/JointAI/articles/SelectingParameters.html}{Parameter Selection}
+#'           for examples how to specify the parameter \code{subset}.
 #'
 #' @export
 summary.JointAI <- function(object, start = NULL, end = NULL, thin = NULL,
-                            quantiles = c(0.025, 0.975), subset = "main", ...) {
+                            quantiles = c(0.025, 0.975), subset = NULL,
+                            warn = TRUE, mess = TRUE, ...) {
 
   if (is.null(object$sample))
-    stop("No mcmc sample.")
+    stop("There is no mcmc sample.")
 
 
   if (is.null(start)) {
@@ -47,28 +41,14 @@ summary.JointAI <- function(object, start = NULL, end = NULL, thin = NULL,
   if (is.null(thin))
     thin <- thin(object$sample)
 
+  MCMC <- get_subset(object, subset, as.list(match.call()), warn = warn)
+
   MCMC <- do.call(rbind,
-                  window(object$MCMC,
+                  window(MCMC,
                          start = start,
                          end = end,
                          thin = thin))
 
-  # coefs <- get_coef_names(object$Mlist, object$K)
-  #
-  # colnames(MCMC)[match(coefs[, 1], colnames(MCMC))] <- coefs[, 2]
-  #
-  # scale_pars <- object$scale_pars
-  # if (!is.null(scale_pars)) {
-  #   # re-scale parameters
-  #   MCMC <- sapply(colnames(MCMC), rescale, object$Mlist$fixed2, scale_pars,
-  #                  MCMC, object$Mlist$refs, object$Mlist$X2_names)
-  # }
-
-  if (!is.null(subset)) {
-    MCMC <- get_subset(subset, MCMC, object)
-  }
-
-
 
   # create results matrix
   statnames <- c("Mean", "SD", paste0(quantiles * 100, "%"), "tail-prob.")
@@ -90,9 +70,13 @@ summary.JointAI <- function(object, start = NULL, end = NULL, thin = NULL,
 
   out$ranefvar <- if (object$analysis_type == "lme")
     stats[grep("^D\\[[[:digit:]]*,[[:digit:]]*\\]", rownames(stats), value = TRUE), -5, drop = FALSE]
-  out$sigma <- if (attr(object$analysis_type, "family") == "gaussian")
+  out$sigma <- if (attr(object$analysis_type, "family") == "gaussian" &
+                   any(grepl(paste0("sigma_", names(object$Mlist$y)), rownames(stats))))
     stats[grep(paste0("sigma_", names(object$Mlist$y)), rownames(stats), value = TRUE), -5, drop = FALSE]
-  out$stats <- stats[!rownames(stats) %in% c(rownames(out$ranefvar), rownames(out$sigma)), ]
+  out$stats <- stats[!rownames(stats) %in% c(rownames(out$ranefvar),
+                                             get_aux(object),
+                                             rownames(out$sigma),
+                                             paste0("tau_", names(object$Mlist$y))), ]
 
   out$analysis_type <- object$analysis_type
   out$size <- nrow(object$data)
@@ -102,6 +86,14 @@ summary.JointAI <- function(object, start = NULL, end = NULL, thin = NULL,
   return(out)
 }
 
+get_aux <- function(object) {
+  aux <- object$Mlist$auxvars
+  unlist(sapply(aux, function(x)
+    if (x %in% names(object$Mlist$refs))
+      attr(object$Mlist$refs[[x]], 'dummies')
+    else x
+  ))
+}
 
 print_type <- function(x) {
   a <- switch(x,
@@ -128,7 +120,7 @@ print.summary.JointAI <- function(x, digits = max(3, .Options$digits - 3), ...)
     cat("Posterior summary of random effects covariance matrix:\n")
     print(x$ranefvar, digits = digits)
   }
-  if (attr(x$analysis_type, "family") %in% c("gaussian", "Gamma")) {
+  if (!is.null(x$sigma)) {
     cat("\n")
     cat("Posterior summary of residual std. deviation:\n")
     print(x$sigma, digits = digits)
@@ -140,8 +132,6 @@ print.summary.JointAI <- function(x, digits = max(3, .Options$digits - 3), ...)
         1, "\n")
   cat("Thinning interval =", x$thin, "\n")
   cat("Number of chains =", x$nchain, "\n")
-  # cat("\n1. Empirical mean and standard deviation for each variable,")
-  # cat("\n   plus standard error of the mean:\n\n")
   cat("\n")
   cat("Number of observations:", x$size, "\n")
   if (x$analysis_type == "lme")
